@@ -82,7 +82,7 @@ TarArch::TarArch( ArkWidget *_gui,
     m_dotslash = false;
     m_filesToAdd = m_filesToRemove = QStringList();
     kdDebug(1601) << "+TarArch::TarArch" << endl;
-    m_archiver_program = Settings::tarExe();
+    m_archiver_program = ArkSettings::tarExe();
     m_unarchiver_program = QString::null;
     verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
 
@@ -92,6 +92,13 @@ TarArch::TarArch( ArkWidget *_gui,
 
     kdDebug(1601) << "TarArch::TarArch:  mimetype is " << m_fileMimeType << endl;
 
+    if ( m_fileMimeType == "application/x-tbz2" )
+    {
+        // ark treats .tar.bz2 as x-tbz, instead of duplicating the mimetype
+        // let's just alias it to the one we already handle.
+        m_fileMimeType = "application/x-tbz";
+    }
+
     if ( m_fileMimeType == "application/x-tar" )
     {
         compressed = false;
@@ -119,6 +126,8 @@ TarArch::~TarArch()
 {
     if ( m_tmpDir )
         delete m_tmpDir;
+    if ( tarptr )
+        delete tarptr;
 }
 
 int TarArch::getEditFlag()
@@ -138,7 +147,7 @@ void TarArch::updateArch()
       else
           fd = NULL;
 
-      KProcess *kp = new KProcess;
+      KProcess *kp = m_currentProcess = new KProcess;
       kp->clearArguments();
       KProcess::Communication flag = KProcess::AllOutput;
       if ( getCompressor() == "lzop" )
@@ -236,7 +245,7 @@ TarArch::open()
     //
     // Now it's essential - used later to decide whether pathnames in the
     // tar archive are plain or start with "./"
-    KProcess *kp = new KProcess;
+    KProcess *kp = m_currentProcess = new KProcess;
 
     *kp << m_archiver_program;
 
@@ -332,27 +341,26 @@ void TarArch::openSecondCreateTempDone()
     {
         kdDebug(1601)  << "Failed to uncompress and open." << endl;
         delete tarptr;
+        tarptr = NULL;
         emit sigOpen(this, false, QString::null, 0 );
     }
     else
     {
         processDir(tarptr->directory(), "");
         delete tarptr;
+        tarptr = NULL;
         // because we aren't using the KProcess method, we have to emit this
         // ourselves.
         emit sigOpen(this, true, m_filename,
                 Arch::Extract | Arch::Delete | Arch::Add | Arch::View );
     }
-
-
-    kdDebug(1601) << "-TarArch::open" << endl;
 }
 
 void TarArch::slotListingDone(KProcess *_kp)
 {
   const QString list = getLastShellOutput();
   FileListView *flv = m_gui->fileList();
-  if (flv!=NULL && flv->count()>0)
+  if (flv!=NULL && flv->totalFiles()>0)
   {
     const QString firstfile = ((FileLVI *) flv->firstChild())->fileName();
     if (list.find(QRegExp(QString("\\s\\./%1[/\\n]").arg(firstfile)))>=0)
@@ -364,8 +372,8 @@ void TarArch::slotListingDone(KProcess *_kp)
     {
       if (list.find(QRegExp(QString("\\s%1[/\\n]").arg(firstfile)))>=0)
       {
+        // archive doesn't have dot-slash
         m_dotslash = false;
-        kdDebug(1601) << k_funcinfo << "archive doesn't have dot-slash" << endl;
       }
       else
       {
@@ -375,13 +383,13 @@ void TarArch::slotListingDone(KProcess *_kp)
   }
 
   delete _kp;
+  _kp = m_currentProcess = NULL;
 }
 
 void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
   // process a KTarDirectory. Called recursively for directories within
   // directories, etc. Prepends to filename root, for relative pathnames.
 {
-  // kdDebug(1601) << "+TarArch::processDir" << endl;
   QStringList list = tardir->entries();
 
   for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
@@ -426,46 +434,32 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
         processDir( (KTarDirectory *)tarEntry, name);
       kapp->processEvents(20);
     }
-  // kdDebug(1601) << "-TarArch::processDir" << endl;
 }
 
 void TarArch::create()
 {
-  kdDebug(1601) << "+TarArch::createArch" << endl;
-
   emit sigCreate(this, true, m_filename,
                  Arch::Extract | Arch::Delete | Arch::Add
                   | Arch::View);
-  kdDebug(1601) << "-TarArch::createArch" << endl;
 }
 
 void TarArch::setHeaders()
 {
-  kdDebug(1601) << "+TarArch::setHeaders" << endl;
-  QStringList list;
+  ColumnList list;
 
-  list.append(FILENAME_STRING);
-  list.append(PERMISSION_STRING);
-  list.append(OWNER_STRING);
-  list.append(GROUP_STRING);
-  list.append(SIZE_STRING);
-  list.append(TIMESTAMP_STRING);
-  list.append(LINK_STRING);
+  list.append(FILENAME_COLUMN);
+  list.append(PERMISSION_COLUMN);
+  list.append(OWNER_COLUMN);
+  list.append(GROUP_COLUMN);
+  list.append(SIZE_COLUMN);
+  list.append(TIMESTAMP_COLUMN);
+  list.append(LINK_COLUMN);
 
-  // which columns to align right
-  int *alignRightCols = new int[2];
-  alignRightCols[0] = 1;
-  alignRightCols[1] = 4;
-
-  m_gui->setHeaders(&list, alignRightCols, 2);
-  delete [] alignRightCols;
-
-  kdDebug(1601) << "-TarArch::setHeaders" << endl;
+  emit headers( list );
 }
 
 void TarArch::createTmp()
 {
-    kdDebug(1601) << "+TarArch::createTmp" << endl;
     if ( compressed )
     {
         if ( !QFile::exists(tmpfile) )
@@ -490,7 +484,7 @@ void TarArch::createTmp()
             else
                 fd = NULL;
 
-            KProcess *kp = new KProcess;
+            KProcess *kp = m_currentProcess = new KProcess;
             kp->clearArguments();
             kdDebug(1601) << "Uncompressor is " << strUncompressor << endl;
             *kp << strUncompressor;
@@ -528,8 +522,6 @@ void TarArch::createTmp()
     {
         emit createTempDone();
     }
-
-    kdDebug(1601) << "-TarArch::createTmp" << endl;
 }
 
 void TarArch::createTmpProgress( KProcess * _proc, char *_buffer, int _bufflen )
@@ -615,7 +607,7 @@ void TarArch::addFile( const QStringList&  urls )
   // those in urls.
   m_bNotifyWhenDeleteFails = false;
   connect( this, SIGNAL( removeDone() ), this, SLOT( deleteOldFilesDone() ) );
-  deleteOldFiles(urls, Settings::replaceOnlyWithNewer());
+  deleteOldFiles(urls, ArkSettings::replaceOnlyWithNewer());
 }
 
 void TarArch::deleteOldFilesDone()
@@ -632,10 +624,10 @@ void TarArch::addFileCreateTempDone()
   disconnect( this, SIGNAL( createTempDone() ), this, SLOT( addFileCreateTempDone() ) );
   QStringList * urls = &m_filesToAdd;
 
-  KProcess *kp = new KProcess;
+  KProcess *kp = m_currentProcess = new KProcess;
   *kp << m_archiver_program;
 
-  if( Settings::replaceOnlyWithNewer())
+  if( ArkSettings::replaceOnlyWithNewer())
     *kp << "uvf";
   else
     *kp << "rvf";
@@ -706,22 +698,21 @@ void TarArch::addFinishedUpdateDone()
   kdDebug(1601) << "-TarArch::addFinishedUpdateDone" << endl;
 }
 
-void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
-                         bool /* viewFriendly */)
+void TarArch::unarchFileInternal()
 {
   kdDebug(1601) << "+TarArch::unarchFile" << endl;
   QString dest;
 
-  if (_destDir.isEmpty() || _destDir.isNull())
+  if (m_destDir.isEmpty() || m_destDir.isNull())
     {
       kdError(1601) << "There was no extract directory given." << endl;
       return;
     }
-  else dest = _destDir;
+  else dest = m_destDir;
 
   QString tmp;
 
-  KProcess *kp = new KProcess;
+  KProcess *kp = m_currentProcess = new KProcess;
   kp->clearArguments();
 
   *kp << m_archiver_program;
@@ -729,9 +720,9 @@ void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
     *kp << "--use-compress-program="+getUnCompressor();
 
   QString options = "-x";
-  if (!Settings::extractOverwrite())
+  if (!ArkSettings::extractOverwrite())
     options += "k";
-  if (Settings::preservePerms())
+  if (ArkSettings::preservePerms())
     options += "p";
   options += "f";
 
@@ -740,10 +731,10 @@ void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
 
   // if the list is empty, no filenames go on the command line,
   // and we then extract everything in the archive.
-  if (_fileList)
+  if (m_fileList)
     {
-      for ( QStringList::Iterator it = _fileList->begin();
-            it != _fileList->end(); ++it )
+      for ( QStringList::Iterator it = m_fileList->begin();
+            it != m_fileList->end(); ++it )
         {
 	    *kp << QString(m_dotslash ? "./" : "")+(*it);
 //	    *kp << (*it);/*.latin1() ;*/
@@ -781,7 +772,7 @@ void TarArch::removeCreateTempDone()
   disconnect( this, SIGNAL( createTempDone() ), this, SLOT( removeCreateTempDone() ) );
 
   QString name, tmp;
-  KProcess *kp = new KProcess;
+  KProcess *kp = m_currentProcess = new KProcess;
   kp->clearArguments();
   *kp << m_archiver_program << "--delete" << "-f" ;
   if (compressed)
@@ -859,7 +850,7 @@ void TarArch::createTmpFinished( KProcess *_kp )
   createTmpInProgress = false;
   fclose(fd);
   delete _kp;
-  _kp = NULL;
+  _kp = m_currentProcess = NULL;
 
 
   kdDebug(1601) << "-TarArch::createTmpFinished" << endl;
@@ -872,7 +863,7 @@ void TarArch::updateFinished( KProcess *_kp )
   fclose(fd);
   updateInProgress = false;
   delete _kp;
-  _kp = NULL;
+  _kp = m_currentProcess = NULL;
 
   kdDebug(1601) << "-TarArch::updateFinished" << endl;
   emit updateDone();
