@@ -1,5 +1,5 @@
 /*
-    $Id: kcalctype.h 392778 2005-02-24 09:21:01Z dfaure $
+    $Id: kcalctype.h 442239 2005-08-02 00:32:37Z kniederk $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -50,9 +50,7 @@
 
 
 #if defined(HAVE_LONG_DOUBLE) && defined(HAVE_L_FUNCS)
-	#define FABS(X)		fabsl(X)
 	#define MODF(X,Y)	modfl(X,Y)
-	#define FMOD(X,Y)	fmodl(X,Y)
 	#define SIN(X)		sinl(X)
 	#define ASIN(X)		asinl(X)
 	#define SINH(X)		sinhl(X)
@@ -76,9 +74,7 @@
 	#define ROUND(X)	roundl(X)
 	#define CALCAMNT_EPSILON	LDBL_EPSILON
 #else
-	#define FABS(X)		fabs(X)
 	#define MODF(X,Y)	modf(X,Y)
-	#define FMOD(X,Y)	fmod(X,Y)
 	#define SIN(X)		sin(X)
 	#define ASIN(X)		asin(X)
 	#define SINH(X)		sinh(X)
