@@ -83,10 +83,10 @@ TopLevel::TopLevel (QWidget *, const char *name)
 
   setupEditWidget();
 
-  resize( QSize(550, 400).expandedTo(minimumSizeHint()));
-  // Show before setupGUI so that adjust() wont be called.
-  show();
-  setupGUI();
+  if (!initialGeometrySet())
+    resize( QSize(550, 400).expandedTo(minimumSizeHint()));
+  setupGUI(ToolBar | Keys | StatusBar | Create);
+  setAutoSaveSettings();
 
   setAcceptDrops(true);
 
@@ -619,11 +619,11 @@ bool TopLevel::queryClose()
                     msg = i18n(""
 	                "Could not save the file.\n"
 	                "Exit anyways?");
-                    switch( KMessageBox::warningYesNo( this, msg ) )
+                    switch( KMessageBox::warningContinueCancel( this, msg, QString::null, KStdGuiItem::quit() ) )
                     {
-                     case KMessageBox::Yes:
+                     case KMessageBox::Continue:
                               return true; // Exit.
-                     case KMessageBox::No:
+                     case KMessageBox::Cancel:
                      default:
                               return false; // Don't exit.
                     }
