@@ -1,8 +1,9 @@
 /*
-    KFloppy
+    
+    This file is part of the KFloppy program, part of the KDE project
     
     Copyright (C) 1997 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
-    Copyright (C) 2004 Nicolas GOUTTE <goutte@kde.org>
+    Copyright (C) 2004, 2005 Nicolas GOUTTE <goutte@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-    */
+*/
 
 
 #include <qlayout.h>
@@ -27,6 +28,7 @@
 #include <qcursor.h>
 #include <qradiobutton.h>
 #include <qbuttongroup.h>
+#include <qwhatsthis.h>
 
 #include <kconfig.h>
 
@@ -40,13 +42,15 @@
 #include <klocale.h>
 #include <kcombobox.h>
 #include <klineedit.h>
+#include <dcopref.h>
+#include <kurl.h>
 
 #include "floppy.h"
 #include "format.h"
 
 FloppyData::FloppyData(QWidget * parent, const char * name)
  : KDialog( parent, name ),
-	formatActions(0L), m_canLowLevel(false)
+	formatActions(0L), m_canLowLevel(false), m_canZeroOut( false )
 {
 
 	formating = false;
@@ -62,23 +66,27 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
         QGridLayout* g1 = new QGridLayout( v1, 3, 2 );
 
-        label1 = new QLabel(this);
-	label1->setText(i18n("Floppy drive:"));
+        deviceComboBox = new KComboBox( false, this, "ComboBox_1" );
+        label1 = new QLabel( deviceComboBox, i18n("Floppy &drive:"), this );
         g1->addWidget( label1, 0, 0, AlignLeft );
+        g1->addWidget( deviceComboBox, 0, 1 );
 
-
-	deviceComboBox = new KComboBox( false, this, "ComboBox_1" );
-	g1->addWidget( deviceComboBox, 0, 1 );
-
-	deviceComboBox->insertItem(i18n("Primary"));
+        // Make the combo box editable, so that the user can enter a device name
+        deviceComboBox->setEditable( true );
+	
+        deviceComboBox->insertItem(i18n("Primary"));
 	deviceComboBox->insertItem(i18n("Secondary"));
 
-        label2 = new QLabel(this);
-	label2->setText(i18n("Size:"));
-        g1->addWidget( label2, 1, 0, AlignLeft );
+	const QString deviceWhatsThis = i18n("<qt>Select the floppy drive.</qt>");
+	
+	QWhatsThis::add(label1, deviceWhatsThis);
+	QWhatsThis::add(deviceComboBox, deviceWhatsThis);
 
-	densityComboBox = new KComboBox( false, this, "ComboBox_1" );
-	g1->addWidget( densityComboBox, 1, 1 );
+        
+        densityComboBox = new KComboBox( false, this, "ComboBox_1" );
+        label2 = new QLabel( densityComboBox, i18n("&Size:"), this);
+        g1->addWidget( label2, 1, 0, AlignLeft );
+        g1->addWidget( densityComboBox, 1, 1 );
 
 #if defined(ANY_LINUX)
 	densityComboBox->insertItem( i18n( "Auto-Detect" ) );
@@ -88,21 +96,35 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	densityComboBox->insertItem(i18n("5.25\" 1.2MB"));
 	densityComboBox->insertItem(i18n("5.25\" 360KB"));
 
+	const QString densityWhatsThis = 
+	    i18n("<qt>This allows you to select the "
+	         "floppy disk's size and density.</qt>");
+	
+	QWhatsThis::add(label2, densityWhatsThis);
+	QWhatsThis::add(densityComboBox, densityWhatsThis);
 
-        label3 = new QLabel(this);
-	label3->setText(i18n("File system:"));
+
+        filesystemComboBox = new KComboBox( false, this, "ComboBox_2" );
+        label3 = new QLabel( filesystemComboBox, i18n("F&ile system:"), this);
         g1->addWidget( label3, 2, 0, AlignLeft );
-
-	filesystemComboBox = new KComboBox( false, this, "ComboBox_2" );
-	g1->addWidget( filesystemComboBox, 2, 1 );
+        g1->addWidget( filesystemComboBox, 2, 1 );
 	g1->setColStretch(1, 1);
 
+#if defined(ANY_LINUX)
+        QWhatsThis::add( label3,
+            i18n( "Linux", "KFloppy supports three file formats under Linux: MS-DOS, Ext2, and Minix" ) );
+#elif defined(ANY_BSD)
+        QWhatsThis::add( label3,
+            i18n( "BSD", "KFloppy supports three file formats under BSD: MS-DOS, UFS, and Ext2" ) );
+#endif
         // If you modify the user visible string, change them also (far) below
 
         QString userFeedBack;
         uint numFileSystems = 0;
 
 #if defined(ANY_LINUX)
+        QWhatsThis::add( filesystemComboBox,
+            i18n( "Linux", "KFloppy supports three file formats under Linux: MS-DOS, Ext2, and Minix" ) );
         if (FATFilesystem::runtimeCheck()) {
             filesystemComboBox->insertItem(i18n("DOS"));
             ++numFileSystems;
@@ -115,10 +137,10 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         if (Ext2Filesystem::runtimeCheck()) {
             filesystemComboBox->insertItem(i18n("ext2"));
             ++numFileSystems;
-            userFeedBack += i18n( "Linux", "Program mke2fs found." );
+            userFeedBack += i18n( "Program mke2fs found." );
         }
         else {
-            userFeedBack += i18n( "Linux", "Program mke2fs <b>not found</b>. Ext2 formatting <b>not available</b>" );
+            userFeedBack += i18n( "Program mke2fs <b>not found</b>. Ext2 formatting <b>not available</b>" );
         }
         userFeedBack += "<br>";
         if (MinixFilesystem::runtimeCheck()) {
@@ -130,6 +152,8 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
             userFeedBack += i18n( "Linux", "Program mkfs.minix <b>not found</b>. Minix formatting <b>not available</b>" );
         }
 #elif defined(ANY_BSD)
+        QWhatsThis::add( filesystemComboBox,
+            i18n( "BSD", "KFloppy supports two file formats under BSD: MS-DOS and UFS" ) );
         if (FATFilesystem::runtimeCheck()) {
             filesystemComboBox->insertItem(i18n("DOS"));
             ++numFileSystems;
@@ -147,23 +171,36 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         else {
             userFeedBack += i18n( "BSD", "Program newfs <b>not found</b>. UFS formatting <b>not available</b>." );
         }
+        userFeedBack += "<br>";
+        if (Ext2Filesystem::runtimeCheck()) {
+            filesystemComboBox->insertItem(i18n("ext2"));
+            ++numFileSystems;
+            userFeedBack += i18n( "Program mke2fs found." );
+        }
+        else {
+            userFeedBack += i18n( "Program mke2fs <b>not found</b>. Ext2 formatting <b>not available</b>" );
+        }
 #endif
 
         v1->addSpacing( 10 );
 
-        buttongroup = new QButtonGroup( this, "ButtonGroup_1" );
-	buttongroup->setFrameStyle( 49 );
-	v1->addWidget( buttongroup );
+        buttongroup = new QButtonGroup( 3, Qt::Vertical, i18n("&Formatting"), this, "ButtonGroup_1" );
 
-        QVBoxLayout* v2 = new QVBoxLayout( buttongroup, 10 );
 
-	quick = new QRadioButton( buttongroup, "RadioButton_2" );
-	quick->setText(i18n( "Q&uick format") );
-        v2->addWidget( quick, AlignLeft );
+        quick = new QRadioButton( i18n( "Q&uick format" ), buttongroup, "RadioButton_2" );
+        QWhatsThis::add( quick,
+            i18n("<qt>Quick format is only a high-level format:"
+                " it creates only a file system.</qt>") );
 
-	fullformat = new QRadioButton( buttongroup, "RadioButton_3" );
-	fullformat->setText(i18n( "Fu&ll format") );
-        v2->addWidget( fullformat, AlignLeft );
+	zerooutformat = new QRadioButton( i18n( "&Zero out and quick format"), buttongroup, "RadioButton_ZeroOutFormat" );
+        QWhatsThis::add( zerooutformat,
+            i18n("<qt>This first erases the floppy by writing zeros and then it creates the file system.</qt>") );
+	
+        fullformat = new QRadioButton( i18n( "Fu&ll format"), buttongroup, "RadioButton_3" );
+        QWhatsThis::add( fullformat,
+            i18n("Full format is a low-level and high-level format. It erases everything on the disk.") );
+
+        v1->addWidget( buttongroup );
 
         // ### TODO: we need some user feedback telling why full formatting is disabled.
         userFeedBack += "<br>";
@@ -177,24 +214,46 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
             quick->setChecked(true);
             userFeedBack += i18n( "Program fdformat <b>not found</b>. Full formatting <b>disabled</b>." );
         }
+        userFeedBack += "<br>";
+        m_canZeroOut = DDZeroOut::runtimeCheck();
+        if ( m_canZeroOut )
+        {
+            zerooutformat->setChecked( true );
+            userFeedBack += i18n( "Program dd found." );
+        }
+        else {
+            zerooutformat->setDisabled(true);
+            userFeedBack += i18n( "Program dd <b>not found</b>. Zeroing-out <b>disabled</b>." );
+        }
         
-	verifylabel = new QCheckBox( buttongroup, "RadioButton_4" );
+	verifylabel = new QCheckBox( this, "CheckBox_Integrity" );
 	verifylabel->setText(i18n( "&Verify integrity" ));
 	verifylabel->setChecked(true);
-	v2->addWidget( verifylabel, AlignLeft );
+	v1->addWidget( verifylabel, AlignLeft );
+        QWhatsThis::add( verifylabel,
+            i18n("<qt>Check this if you want the floppy disk to be checked after formatting."
+            " Please note that the floppy will be checked twice if you have selected full formatting.</qt>") );
 
-	labellabel = new QCheckBox( buttongroup, "RadioButton_4" );
-	labellabel->setText(i18n( "Volume &label:") );
+	labellabel = new QCheckBox( this, "Checkbox_Label" );
+	labellabel->setText(i18n( "Volume la&bel:") );
 	labellabel->setChecked(true);
-        v2->addWidget( labellabel, AlignLeft );
+        v1->addWidget( labellabel, AlignLeft );
+        QWhatsThis::add( labellabel,
+            i18n("<qt>Check this if you want a volume label for your floppy."
+            " Please note that Minix does not support labels at all.</qt>") );
 
-        QHBoxLayout* h2 = new QHBoxLayout( v2 );
+        QHBoxLayout* h2 = new QHBoxLayout( v1 );
         h2->addSpacing( 20 );
 
-	lineedit = new KLineEdit( buttongroup, "Lineedit" );
+	lineedit = new KLineEdit( this, "Lineedit" );
+        // ### TODO ext2 supports 16 characters. Minix has not any label. UFS?
 	lineedit->setText(i18n( "Volume label, maximal 11 characters", "KDE Floppy" ) );
 	lineedit->setMaxLength(11);
         h2->addWidget( lineedit, AlignRight );
+        QWhatsThis::add( lineedit,
+            i18n("<qt>This is for the volume label."
+            " Due to a limitation of MS-DOS the label can only be 11 characters long."
+            " Please note that Minix does not support labels, whatever you enter here.</qt>") );
 
 	connect(labellabel,SIGNAL(toggled(bool)),lineedit,SLOT(setEnabled(bool)));
 
@@ -207,6 +266,8 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
             formatbutton->setDisabled(false); // We have not any helper program for creating any file system
 	connect(formatbutton,SIGNAL(clicked()),this,SLOT(format()));
         v3->addWidget( formatbutton );
+        QWhatsThis::add( formatbutton,
+            i18n("<qt>Click here to start formatting.</qt>") );
 
         v3->addStretch( 1 );
 
@@ -228,6 +289,8 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	frame = new QLabel( this, "NewsWindow" );
 	frame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
 	frame->setAlignment(WordBreak|ExpandTabs);
+        QWhatsThis::add( frame,
+            i18n("<qt>This is the status window, where error messages are displayed.</qt>") );
 
         QString frameText( userFeedBack );
         frameText.prepend( "<qt>" );
@@ -240,6 +303,9 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         progress->setDisabled( true );
         ml->addWidget( progress );
 
+	QWhatsThis::add(progress,
+			i18n("<qt>Shows progress of the format.</qt>"));
+
 	readSettings();
 	setWidgets();
 
@@ -284,12 +350,14 @@ void FloppyData::show() {
 
 bool FloppyData::findDevice()
 {
+    // Note: this function does not handle user-given devices
+
   drive=-1;
   if( deviceComboBox->currentText() == i18n("Primary") )
   {
     drive=0;
   }
-  if( deviceComboBox->currentText() == i18n("Secondary") )
+  else if( deviceComboBox->currentText() == i18n("Secondary") )
   {
     drive=1;
   }
@@ -322,12 +390,31 @@ bool FloppyData::findDevice()
 
 bool FloppyData::setInitialDevice(const QString& dev)
 {
+
+  QString newDevice = dev;
+
+  KURL url( newDevice );
+  if( url.isValid() && ( url.protocol() == "media" || url.protocol() == "system" ) ) {
+    QString name = url.fileName();
+
+    DCOPRef mediamanager( "kded", "mediamanager" );
+    DCOPReply reply = mediamanager.call("properties(QString)", name);
+    if (!reply.isValid()) {
+      kdError() << "Invalid reply from mediamanager" << endl;
+    } else {
+      QStringList properties = reply;
+      newDevice = properties[5];
+    }
+  }
+
   int drive = -1;
-  if (dev.startsWith("/dev/fd0"))
+  if ( newDevice.startsWith("/dev/fd0") )
     drive = 0;
-  if (dev.startsWith("/dev/fd1"))
+  if ( newDevice.startsWith("/dev/fd1"))
     drive = 1;
 
+  // ### TODO user given devices
+    
   bool ok = (drive>=0);
   if (ok)
     deviceComboBox->setCurrentItem(drive);
@@ -356,6 +443,7 @@ void FloppyData::setEnabled(bool b)
   buttongroup->setEnabled(b);
   quick->setEnabled(b);
   fullformat->setEnabled(b && m_canLowLevel);
+  zerooutformat->setEnabled(b && m_canZeroOut);
   verifylabel->setEnabled(b);
   labellabel->setEnabled(b);
   lineedit->setEnabled(b && labellabel->isChecked() );
@@ -393,22 +481,59 @@ void FloppyData::format(){
 
   frame->clear();
 
-  if (KMessageBox::warningContinueCancel(0,
-   i18n("Formatting will erase all data on the disk.\n"
-        "Are you sure you wish to proceed?"), i18n("Proceed?") ) !=
-	KMessageBox::Continue)
+    const QString currentComboBoxDevice (  deviceComboBox->currentText() );
+    const bool userDevice = ( currentComboBoxDevice.startsWith ("/dev/") );
+
+#ifdef ANY_BSD
+    if ( userDevice && filesystemComboBox->currentText() != i18n("UFS"))
+    {
+        KMessageBox::error( this, i18n("BSD", "Formatting with BSD on a user-given device is only possible with UFS") );
+        return;
+    }
+    // no "else" !
+#endif    
+    if ( userDevice && ( quick->isChecked() || zerooutformat->isChecked() ) ) 
+    {
+        if (KMessageBox::warningContinueCancel( this,
+            i18n("<qt>Formatting will erase all data on the device:<br/><b>%1</b><br/>"
+                "(Please check the correctness of the device name.)<br/>"
+                "Are you sure you wish to proceed?</qt>").arg( currentComboBoxDevice )
+                , i18n("Proceed?") ) != KMessageBox::Continue)
+            {
+                return;
+            }
+    }
+    else if ( userDevice )
+    {
+        // The user has selected full formatting on a user-given device. That is not supported yet!
+        KMessageBox::error( this, "Full formatting of a user-given device is not possible!" );
+        return;
+    }
+    else
+    {
+        if (KMessageBox::warningContinueCancel( this,
+            i18n("Formatting will erase all data on the disk.\n"
+            "Are you sure you wish to proceed?"), i18n("Proceed?") ) !=
+            KMessageBox::Continue)
         {
-	return;
-	}
+            return;
+        }
+    }
 
   // formatbutton->setText(i18n("A&bort"));
   setEnabled(false);
 
-	if (!findDevice())
+        // Erase text box
+        frame->setText( QString::null );
+
+    if ( !userDevice )
+    {
+        if ( !findDevice() )
 	{
 		reset();
 		return;
 	}
+    }
 
 	if (formatActions) delete formatActions;
 	formatActions = new KFActionQueue(this);
@@ -418,12 +543,31 @@ void FloppyData::format(){
 	connect(formatActions,SIGNAL(done(KFAction *,bool)),
 		this,SLOT(reset()));
 
-	if (quick->isChecked())
+	if ( quick->isChecked())
 	{
 		formating=false;
 		// No fdformat to push
 	}
-	else
+        else if ( zerooutformat->isChecked() )
+        {
+            DDZeroOut* f = new DDZeroOut( this );
+            if ( userDevice )
+            {
+                f->configureDevice( currentComboBoxDevice );
+            }
+            else
+            {
+                f->configureDevice( drive, blocks );
+            }
+            formatActions->queue(f);
+        }
+	else if ( userDevice )
+        {
+            // We should not have got here, assume quick format
+            formating=false;
+            // No fdformat to push
+        }
+        else
 	{
 		FDFormat *f = new FDFormat(this);
 		f->configureDevice(drive,blocks);
@@ -434,49 +578,43 @@ void FloppyData::format(){
 	if ( filesystemComboBox->currentText() == i18n("DOS") )
 	{
 		FATFilesystem *f = new FATFilesystem(this);
-		connect(f,SIGNAL(status(const QString &,int)),
-			this,SLOT(formatStatus(const QString &,int)));
-		connect(f,SIGNAL(done(KFAction *,bool)),
-			this,SLOT(reset()));
 		f->configure(verifylabel->isChecked(),
 			labellabel->isChecked(),
 			lineedit->text());
-		f->configureDevice(drive,blocks);
+                if ( userDevice )
+                {
+                    f->configureDevice( currentComboBoxDevice );
+                }
+                else
+                {
+                    f->configureDevice(drive,blocks);
+                }
 		formatActions->queue(f);
 	}
-#ifdef ANY_LINUX
+
 	else if ( filesystemComboBox->currentText() == i18n("ext2") )
 	{
 		Ext2Filesystem *f = new Ext2Filesystem(this);
 		f->configure(verifylabel->isChecked(),
 			labellabel->isChecked(),
 			lineedit->text());
-		if (f)
-		{
-			connect(f,SIGNAL(status(const QString &,int)),
-				this,SLOT(formatStatus(const QString &,int)));
-			connect(f,SIGNAL(done(KFAction *,bool)),
-				this,SLOT(reset()));
-			f->configureDevice(drive,blocks);
-			formatActions->queue(f);
-		}
+                if ( userDevice )
+                {
+                    f->configureDevice( currentComboBoxDevice );
+                }
+                else
+                {
+                    f->configureDevice(drive,blocks);
+                }
+                formatActions->queue(f);
 	}
-#endif
 
 #ifdef ANY_BSD
 	else if ( filesystemComboBox->currentText() == i18n("UFS") )
 	{
 		FloppyAction *f = new UFSFilesystem(this);
-
-		if (f)
-		{
-			connect(f,SIGNAL(status(const QString &,int)),
-				this,SLOT(formatStatus(const QString &,int)));
-			connect(f,SIGNAL(done(KFAction *,bool)),
-				this,SLOT(reset()));
-			f->configureDevice(drive,blocks);
-			formatActions->queue(f);
-		}
+                f->configureDevice(drive,blocks);
+                formatActions->queue(f);
 	}
 #endif
 
@@ -487,15 +625,15 @@ void FloppyData::format(){
 		f->configure(verifylabel->isChecked(),
 			labellabel->isChecked(),
 			lineedit->text());
-		if (f)
-		{
-			connect(f,SIGNAL(status(const QString &,int)),
-				this,SLOT(formatStatus(const QString &,int)));
-			connect(f,SIGNAL(done(KFAction *,bool)),
-				this,SLOT(reset()));
-			f->configureDevice(drive,blocks);
-			formatActions->queue(f);
-		}
+                if ( userDevice )
+                {
+                    f->configureDevice( currentComboBoxDevice );
+                }
+                else
+                {
+                    f->configureDevice(drive,blocks);
+                }
+		formatActions->queue(f);
 	}
 #endif
 
@@ -508,7 +646,17 @@ void FloppyData::formatStatus(const QString &s,int p)
 {
     kdDebug(2002) << "FloppyData::formatStatus: " << s << " : "  << p << endl;
 	if (!s.isEmpty())
-		frame->setText(s);
+        {
+            const QString oldText ( frame->text() );
+            if ( oldText.isEmpty() )
+            {
+                frame->setText( s );
+            }
+            else
+            {
+                frame->setText( oldText + '\n' + s );
+            }
+        }
 
 	if ((0<=p) && (p<=100))
 		progress->setValue(p);
@@ -519,17 +667,13 @@ void FloppyData::writeSettings(){
         config = kapp->config();
 	config->setGroup("GeneralData");
 
-	densityconfig = densityComboBox->currentText();
-	densityconfig = densityconfig.stripWhiteSpace();
-	filesystemconfig = filesystemComboBox->currentText();
-	filesystemconfig = filesystemconfig.stripWhiteSpace();
-	driveconfig = deviceComboBox->currentText();
-	driveconfig = driveconfig.stripWhiteSpace();
+	densityconfig = densityComboBox->currentText().stripWhiteSpace();
+	filesystemconfig = filesystemComboBox->currentText().stripWhiteSpace();
+	driveconfig = deviceComboBox->currentText().stripWhiteSpace();
 
 	quickformatconfig = quick->isChecked();
 
-	labelnameconfig = lineedit->text();
-	labelnameconfig = labelnameconfig.stripWhiteSpace();
+	labelnameconfig = lineedit->text().stripWhiteSpace();
 
 	labelconfig = labellabel->isChecked();
 
@@ -560,6 +704,7 @@ void FloppyData::readSettings(){
 	driveconfig = config->readEntry( "FloppyDrive", i18n("Primary") );
 	densityconfig = config->readEntry( "Density", i18n("3.5\" 1.44MB") );
 	filesystemconfig = config->readEntry( "Filesystem", i18n("DOS") );
+
 }
 
 void FloppyData::setWidgets(){
@@ -567,7 +712,6 @@ void FloppyData::setWidgets(){
   labellabel->setChecked(labelconfig);
   verifylabel->setChecked(verifyconfig);
   quick->setChecked(quickformatconfig || !m_canLowLevel);
-
   fullformat->setChecked(!quickformatconfig && m_canLowLevel);
   lineedit->setText(labelnameconfig);
 
