@@ -1,6 +1,6 @@
 /*
 
-    KFloppy
+    This file is part of the KFloppy program, part of the KDE project
     
     Copyright (C) 2002 Adriaan de Groot <groot@kde.org>
     Copyright (C) 2004, 2005 Nicolas GOUTTE <goutte@kde.org>
@@ -18,7 +18,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-    */
+*/
 
 
 #include <unistd.h>
@@ -133,7 +133,6 @@ void KFActionQueue::queue(KFAction *p)
 
 	if (!success)
 	{
-            // ### TODO: the user must be told that the action has failed.
 		DEBUGS("Action failed.");
 		emit done(this,false);
 		return;
@@ -236,7 +235,6 @@ fdinfo fdtable[] =
 FloppyAction::FloppyAction(QObject *p) :
 	KFAction(p),
 	deviceInfo(0L),
-	deviceName(0L),
 	theProcess(0L)
 {
 	DEBUGSETUP;
@@ -251,13 +249,20 @@ void FloppyAction::quit()
 	KFAction::quit();
 }
 
+bool FloppyAction::configureDevice( const QString& newDeviceName )
+{
+    deviceInfo = 0; // We have not any idea what the device is
+    deviceName = newDeviceName;
+    return true; // No problem!
+}
+
 bool FloppyAction::configureDevice(int drive,int density)
 {
 	DEBUGSETUP;
 	const char *devicename = 0L;
 
 	deviceInfo=0L;
-	deviceName=0L;
+	deviceName = QString::null;
 
 	if ((drive<0) || (drive>1))
 	{
@@ -325,12 +330,20 @@ void FloppyAction::processDone(KProcess *p)
 
 	if (p->normalExit())
 	{
-		emit status(QString::null,100);
-		emit done(this,!p->exitStatus());
+	        if (p->exitStatus() == 0)
+	        {
+			emit status(QString::null,100);
+			emit done(this,true);
+		}
+		else
+		{
+			emit status(i18n("The program %1 terminated with an error.").arg(theProcessName),100);
+			emit done(this,false);
+		}
 	}
 	else
 	{
-		emit status(i18n("%1 terminated abnormally.").arg(theProcessName),100);
+		emit status(i18n("The program %1 terminated abnormally.").arg(theProcessName),100);
 		emit done(this,false);
 	}
 }
@@ -391,8 +404,9 @@ bool FDFormat::configure(bool v)
 {
 	DEBUGSETUP;
 
-	if (!deviceInfo || !deviceName)
+	if ( !deviceInfo || deviceName.isEmpty() )
 	{
+                emit status( i18n("Internal error: device not correctly defined."), -1 );
 		emit done(this,false);
 		return;
 	}
@@ -487,7 +501,7 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
             if ( regexp.search( s ) > -1 )
             {
                 const int track = regexp.cap(1).toInt();
-                emit status(i18n("Low-level formatting error at track %1!").arg(track), -1);
+                emit status(i18n("Low-level formatting error at track %1.").arg(track), -1);
             }
             else
             {
@@ -504,12 +518,18 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
                     "have selected a valid floppy drive."),-1);
             return;
 	}
-        else if ( ( s.find( "ioctl" ) != -1 )
-            || ( s.find( "busy" ) != -1 ) ) // "Device or resource busy"
+        else if (s.find("busy")!=-1) // "Device or resource busy"
+        {
+            emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
+            return;
+        }
+        // Be careful to leave "iotcl" as last before checking numbers
+        else if (s.find("ioctl")!=-1)
         {
             emit status(i18n("Low-level format error: %1").arg(s),-1);
             return;
         }
+        // Check for numbers at last (as /dev/fd0u1440 has numbers too)
         else if ( regexp.search(s) > -1 )
         {
             // Normal track number (formatting or verifying)
@@ -525,6 +545,77 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
 }
 
 
+/* static */ QString DDZeroOut::m_ddName = QString::null;
+
+DDZeroOut::DDZeroOut(QObject *p) :
+    FloppyAction(p)
+{
+    kdDebug(KFAREA) << (__PRETTY_FUNCTION__) << endl;
+    theProcessName = QString::fromLatin1("dd");
+    setName("DD");
+}
+
+/* static */ bool DDZeroOut::runtimeCheck()
+{
+    m_ddName = findExecutable("dd");
+    return (!m_ddName.isEmpty());
+}
+
+/* virtual */ void DDZeroOut::exec()
+{
+    kdDebug(KFAREA) << (__PRETTY_FUNCTION__) << endl;
+
+    if ( deviceName.isEmpty() )
+    {
+        emit status( i18n("Internal error: device not correctly defined."), -1 );
+        emit done( this, false );
+        return;
+    }
+
+    if ( m_ddName.isEmpty() )
+    {
+        emit status( i18n("Cannot find dd."), -1 );
+        emit done( this, false );
+        return;
+    }
+
+    delete theProcess;
+    theProcess = new KProcess;
+
+    *theProcess << m_ddName ;
+
+    *theProcess << "if=/dev/zero" ;
+    *theProcess << "of="+deviceName;
+
+    if ( !startProcess() )
+    {
+            emit status( i18n("Could not start dd."), -1 );
+            emit done( this, false );
+    }
+
+}
+
+void DDZeroOut::processDone(KProcess *p)
+{
+    kdDebug(KFAREA) << (__PRETTY_FUNCTION__) << endl;
+
+    if (p!=theProcess)
+    {
+            kdDebug(KFAREA) << "Strange process exited." << endl;
+            return;
+    }
+
+    /**
+     * As we do not give a number of blocks to dd(1), it will stop
+     * with the error "No space left on device"
+     *
+     * ### TODO: really check if the exit is not on an other error and then abort the formatting
+     */
+    emit status(QString::null,100);
+    emit done(this,true);
+}
+
+
 
 /* static */ QString FATFilesystem::newfs_fat = QString::null ;
 
@@ -568,8 +659,14 @@ void FATFilesystem::exec()
 {
 	DEBUGSETUP;
 
-	if (!deviceInfo || !deviceName)
+        
+	if (
+#ifdef ANY_BSD // BSD needs the deviceInfo for the block count
+            !deviceInfo ||
+#endif
+            deviceName.isEmpty())
 	{
+                emit status( i18n("Internal error: device not correctly defined."), -1 );
 		emit done(this,false);
 		return;
 	}
@@ -612,7 +709,32 @@ void FATFilesystem::exec()
 	}
 }
 
-
+void FATFilesystem::processStdOut(KProcess *, char *b, int l)
+{
+#ifdef ANY_BSD
+    // ### TODO: do some checks
+#elif defined(ANY_LINUX)
+    QString s ( QString::fromLatin1( b, l ) );
+    kdDebug(KFAREA) << s << endl;
+    if (s.find("mounted file system")!=-1) // "/dev/fd0 contains a mounted file system
+    {
+        emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
+        return;
+    }
+    else if (s.find("busy")!=-1) // "Device or resource busy"
+    {
+        emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
+        return;
+    }
+# if 0
+    else if ( s.find( "mkdosfs" ) != -1 ) // DEBUG: get the program header and show it!
+    {
+        emit status( s, -1 );
+        return;
+    }
+# endif
+#endif
+}
 
 
 
@@ -643,15 +765,16 @@ void UFSFilesystem::exec()
 {
 	DEBUGSETUP;
 
-	if (!deviceInfo || !deviceName)
+	if ( deviceName.isEmpty() )
 	{
+                emit status( i18n("Internal error: device not correctly defined."), -1 );
 		emit done(this,false);
 		return;
 	}
 
 	if (newfs.isEmpty())
 	{
-		emit status(i18n("Cannot find a program to create UFS filesystems."),-1);
+		emit status(i18n("BSD", "Cannot find a program to create UFS filesystems."),-1);
 		emit done(this,false);
 		return;
 	}
@@ -660,12 +783,16 @@ void UFSFilesystem::exec()
 	KProcess *p = theProcess = new KProcess;
 
 	*p << newfs;
-	*p << "-T" << QString("fd%1").arg(deviceInfo->blocks)
-		<< deviceName;
+        
+        // ### TODO: is it still needed? (FreeBSD 5.3's man page says: "For backward compatibility.")
+        if ( deviceInfo )
+           *p << "-T" << QString("fd%1").arg(deviceInfo->blocks);
+
+        *p << deviceName;
 
 	if (!startProcess())
 	{
-		emit status(i18n("Cannot start UFS format program."),-1);
+		emit status(i18n("BSD", "Cannot start UFS format program."),-1);
 		emit done(this,false);
 	}
 }
@@ -673,7 +800,6 @@ void UFSFilesystem::exec()
 
 
 
-#ifdef ANY_LINUX
 /* static */ QString Ext2Filesystem::newfs = QString::null ;
 
 Ext2Filesystem::Ext2Filesystem(QObject *parent) :
@@ -714,8 +840,13 @@ void Ext2Filesystem::exec()
 {
 	DEBUGSETUP;
 
-	if (!deviceInfo || !deviceName)
+	if (
+#ifdef ANY_BSD // BSD needs the deviceInfo for the block count
+            !deviceInfo ||
+#endif
+            deviceName.isEmpty() )
 	{
+                emit status( i18n("Internal error: device not correctly defined."), -1 );
 		emit done(this,false);
 		return;
 	}
@@ -744,9 +875,27 @@ void Ext2Filesystem::exec()
 	}
 }
 
-
-
+void Ext2Filesystem::processStdOut(KProcess *, char *b, int l)
+{
+#ifdef ANY_BSD
+    // ### TODO: do some checks
+#elif defined(ANY_LINUX)
+    QString s ( QString::fromLatin1( b, l ) );
+    kdDebug(KFAREA) << s << endl;
+    if (s.find("mounted")!=-1) // "/dev/fd0 is mounted; will not make a filesystem here!"
+    {
+        emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
+        return;
+    }
+    else if (s.find("busy")!=-1) // "Device or resource busy"
+    {
+        emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
+        return;
+    }
 #endif
+}
+
+
 
 #ifdef ANY_LINUX
 /* static */ QString MinixFilesystem::newfs = QString::null ;
@@ -789,8 +938,9 @@ void MinixFilesystem::exec()
 {
 	DEBUGSETUP;
 
-	if (!deviceInfo || !deviceName)
+	if ( deviceName.isEmpty() )
 	{
+                emit status( i18n("Internal error: device not correctly defined."), -1 );
 		emit done(this,false);
 		return;
 	}
@@ -819,6 +969,22 @@ void MinixFilesystem::exec()
 	}
 }
 
+void MinixFilesystem::processStdOut(KProcess *, char *b, int l)
+{
+    QString s ( QString::fromLatin1( b, l ) );
+    kdDebug(KFAREA) << s << endl;
+    if (s.find("mounted")!=-1) // "mkfs.minix: /dev/fd0 is mounted; will not make a filesystem here!"
+    {
+        emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
+        return;
+    }
+    else if (s.find("busy")!=-1) // "Device or resource busy"
+    {
+        emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
+        return;
+    }
+}
+
 #endif
 
 #include "format.moc"
