@@ -50,7 +50,6 @@
 #include <kprocess.h>
 #include <kprocio.h>
 #include <kaboutapplication.h>
-#include <kaction.h>
 #include <kurlrequester.h>
 #include <ktip.h>
 #include <kurldrag.h>
@@ -276,7 +275,7 @@ void  MyView::encryptDroppedFile()
         QStringList opts;
         KgpgLibrary *lib=new KgpgLibrary(this,KGpgSettings::pgpExtension());
 	connect(lib,SIGNAL(systemMessage(QString,bool)),this,SLOT(busyMessage(QString,bool)));
-        if (KGpgSettings::encryptFilesTo()) {
+        if (KGpgSettings::fileKey()!=QString::null) {
                 if (KGpgSettings::allowUntrustedKeys())
                         opts<<"--always-trust";
                 if (KGpgSettings::asciiArmor())
@@ -285,7 +284,7 @@ void  MyView::encryptDroppedFile()
                         opts<<"--throw-keyid";
                 if (KGpgSettings::pgpCompatibility())
                         opts<<"--pgp6";
-                lib->slotFileEnc(droppedUrls,opts,KGpgSettings::fileEncryptionKey().left(8),goDefaultKey);
+                lib->slotFileEnc(droppedUrls,opts,QStringList::split(" ",KGpgSettings::fileKey()),goDefaultKey);
         } else
                 lib->slotFileEnc(droppedUrls,QString::null,QString::null,goDefaultKey);
 }
@@ -576,7 +575,7 @@ void  MyView::readOptions()
         } else {
                 QString path = KGpgSettings::gpgConfigPath();
                 if (path.isEmpty()) {
-                        if (KMessageBox::questionYesNo(0,"<qt>You did not set a path to your GnuPG config file.<br>This may bring some surprising results in KGpg's execution.<br>Would you like to start KGpg's Wizard to fix this problem ?</qt>")==KMessageBox::Yes)
+                        if (KMessageBox::questionYesNo(0,i18n("<qt>You did not set a path to your GnuPG config file.<br>This may bring some surprising results in KGpg's execution.<br>Would you like to start KGpg's Wizard to fix this problem ?</qt>"),QString::null,i18n("Start Wizard"),i18n("Do Not Start"))==KMessageBox::Yes)
                                 startWizard();
                 } else {
                         QStringList groups=KgpgInterface::getGpgGroupNames(path);
@@ -620,7 +619,7 @@ void  MyView::startWizard()
         if (!QFile(confPath).exists()) {
                 confPath=gpgHome+"gpg.conf";
                 if (!QFile(confPath).exists()) {
-                        if (KMessageBox::questionYesNo(this,i18n("<qt><b>The GnuPG configuration file was not found</b>. Please make sure you have GnuPG installed. Should KGpg try to create a config file ?</qt>"))==KMessageBox::Yes) {
+                        if (KMessageBox::questionYesNo(this,i18n("<qt><b>The GnuPG configuration file was not found</b>. Please make sure you have GnuPG installed. Should KGpg try to create a config file ?</qt>"),QString::null,i18n("Create Config"),i18n("Do Not Create"))==KMessageBox::Yes) {
                                 confPath=gpgHome+"options";
                                 QFile file(confPath);
                                 if ( file.open( IO_WriteOnly ) ) {
@@ -776,9 +775,9 @@ kgpgapplet::kgpgapplet(QWidget *parent, const char *name)
         w=new MyView(this);
         w->show();
         KPopupMenu *conf_menu=contextMenu();
-        KAction *KgpgEncryptClipboard = new KAction(i18n("&Encrypt Clipboard"), 0, 0,w, SLOT(clipEncrypt()),actionCollection(),"clip_encrypt");
-        KAction *KgpgDecryptClipboard = new KAction(i18n("&Decrypt Clipboard"), 0, 0,w, SLOT(clipDecrypt()),actionCollection(),"clip_decrypt");
-	KAction *KgpgSignClipboard = new KAction(i18n("&Sign/Verify Clipboard"), 0, 0,w, SLOT(clipSign()),actionCollection(),"clip_sign");
+        KgpgEncryptClipboard = new KAction(i18n("&Encrypt Clipboard"), "kgpg", 0,w, SLOT(clipEncrypt()),actionCollection(),"clip_encrypt");
+        KgpgDecryptClipboard = new KAction(i18n("&Decrypt Clipboard"), 0, 0,w, SLOT(clipDecrypt()),actionCollection(),"clip_decrypt");
+	KgpgSignClipboard = new KAction(i18n("&Sign/Verify Clipboard"), "signature", 0,w, SLOT(clipSign()),actionCollection(),"clip_sign");
         KAction *KgpgOpenEditor;
 	if (KGpgSettings::leftClick()==KGpgSettings::EnumLeftClick::KeyManager)
 	KgpgOpenEditor = new KAction(i18n("&Open Editor"), "edit", 0,parent, SLOT(slotOpenEditor()),actionCollection(),"kgpg_editor");
@@ -787,6 +786,9 @@ kgpgapplet::kgpgapplet(QWidget *parent, const char *name)
 	
 	KAction *KgpgOpenServer = new KAction(i18n("&Key Server Dialog"), "network", 0,this, SLOT(slotOpenServerDialog()),actionCollection(),"kgpg_server");
         KAction *KgpgPreferences=KStdAction::preferences(this, SLOT(showOptions()), actionCollection());
+
+	connect (conf_menu,SIGNAL(aboutToShow()),this,SLOT(checkMenu()));
+
         KgpgEncryptClipboard->plug(conf_menu);
         KgpgDecryptClipboard->plug(conf_menu);
 	KgpgSignClipboard->plug(conf_menu);
@@ -797,6 +799,23 @@ kgpgapplet::kgpgapplet(QWidget *parent, const char *name)
 }
 
 
+void kgpgapplet::checkMenu()
+{
+	KgpgDecryptClipboard->setEnabled(false);
+	if ((kapp->clipboard()->text(w->clipboardMode).isEmpty()))
+	{
+		KgpgEncryptClipboard->setEnabled(false);
+		KgpgSignClipboard->setEnabled(false);
+	}
+	else
+	{
+		KgpgEncryptClipboard->setEnabled(true);
+		if (kapp->clipboard()->text(w->clipboardMode).stripWhiteSpace().startsWith("-----BEGIN"))
+		KgpgDecryptClipboard->setEnabled(true);
+		KgpgSignClipboard->setEnabled(true);
+	}
+}
+
 void kgpgapplet::showOptions()
 {
 QByteArray data;
