@@ -1172,6 +1172,7 @@ class CHexBuffer : public QByteArray
     inline QString &url( void );
     bool hasFileName( void );
     inline void setUrl( const QString &url );
+    inline void setModified( bool modified );
     inline const QDateTime &diskModifyTime( void );
     
 
@@ -1467,6 +1468,11 @@ inline bool CHexBuffer::modified( void )
   return( mDocumentModified );
 }
 
+inline void CHexBuffer::setModified( bool modified )
+{
+  mDocumentModified = modified;
+}
+
 inline uint CHexBuffer::undoState( void )
 {
   return( (mUndoIndex > 0 ? UndoOk : 0) | 
