@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -46,7 +46,6 @@ enum EHexError
   Err_Busy,
   Err_IllegalRange,
   Err_OperationAborted,
-  Err_KioInProgress,
   Err_OpenWriteFailed,
   Err_OpenReadFailed,
   Err_MAXERROR         // Must be the last
