@@ -18,7 +18,7 @@
  *
  */
 
-#include <iostream>
+// kate: space-indent on; indent-width 2; replace-tabs on;
 
 #include <qptrlist.h>
 #include <qsignalmapper.h>
@@ -34,6 +34,7 @@
 #include <kstdaction.h>
 #include <ktoolbarbutton.h>
 #include <kdebug.h>
+#include <kurl.h>
 #include <kurldrag.h>
 
 #include "dialog.h"
@@ -131,10 +132,7 @@ actionCollection());
    
   mAction.insert     = new KAction( i18n("&Insert..."), CTRL+Key_I,
     editor(), SLOT(insertFile()), actionCollection(), "insert_file" );
-  mAction.openRecent = KStdAction::openRecent(0, 0, actionCollection() );
-  connect( mAction.openRecent->popupMenu(), SIGNAL(activated(int )),
-     this, SLOT( recentFile(int) ) );
-
+  mAction.openRecent = KStdAction::openRecent( this, SLOT( slotFileOpenRecent( const KURL& ) ), actionCollection() );
   mAction.save       = KStdAction::save( editor(), SLOT(save()), actionCollection() );
   mAction.saveAs     = KStdAction::saveAs( editor(), SLOT(saveAs()), actionCollection() );
   mAction.revert     = KStdAction::revert( editor(), SLOT(reload()), actionCollection() );
@@ -310,6 +308,7 @@ actionCollection());
   QPopupMenu *documentMenu = (QPopupMenu *)factory()->container("documents", this);
   hexView()->setDocumentMenu(documentMenu);
   connect(documentMenu, SIGNAL(activated(int)), SLOT(documentMenuCB(int)));
+
 }
 
 
@@ -354,7 +353,7 @@ void KHexEdit::setupStatusBar( void )
 
 void KHexEdit::removeRecentFiles( void )
 {
-  mAction.openRecent->clear();
+  mAction.openRecent->clearURLList();
 }
 
 
@@ -375,40 +374,37 @@ void KHexEdit::initialize( bool openFiles )
   mAction.showFullPath->setChecked( mShowFullPath );
   showFullPath();
 
-
-  if( mAction.openRecent->popupMenu()->count() > 0 && openFiles == true )
+  if ( openFiles && editor()->openFile() != SDisplayMisc::none )
   {
-    if( editor()->openFile() == SDisplayMisc::allRecent )
-    {
-      for( uint i=0; i < mAction.openRecent->popupMenu()->count(); i++ )
-      {
-	mStartupFileList.append( mAction.openRecent->popupMenu()->text(i) );
-	if( editor()->gotoStartupOffset() == true &&
-	    mRecentOffsetList.count() > i )
-	{
-	  mStartupOffsetList.append( *mRecentOffsetList.at(i) );
-	}
-	else
-	{
-	  mStartupOffsetList.append( QString("0") );
-	}
-      }
-    }
-    else if( editor()->openFile() == SDisplayMisc::mostRecent )
-    {
-      mStartupFileList.append( mAction.openRecent->popupMenu()->text(0) );
-      if( editor()->gotoStartupOffset() == true &&
-	  mRecentOffsetList.count() > 0 )
-      {
-	mStartupOffsetList.append( *mRecentOffsetList.at(0) );
-      }
-      else
-      {
-	mStartupOffsetList.append( QString("0") );
-      }
-    }
-  }
+    // Code modified from kdelibs/kdeui/kactionclasses.cpp KRecentFilesAction::loadEntries
+      
+    KConfig* config = kapp->config();
 
+    const QString oldGroup = config->group();
+    
+    const QString groupname = "RecentFiles";
+    config->setGroup( groupname );
+    
+        // read file list
+    unsigned int maxItems = mAction.openRecent->maxItems();
+    if ( editor()->openFile() == SDisplayMisc::mostRecent )
+        maxItems = 1;
+    for( unsigned int i = 1 ; i <= maxItems ; i++ )
+    {
+        const QString key = QString( "File%1" ).arg( i );
+        const QString value = config->readPathEntry( key );
+    
+        if (!value.isEmpty())
+        {
+            mStartupFileList.append( value );
+            mStartupOffsetList.append( "0" ); // ### TODO find a way to still have kept offsets
+        }
+    }
+
+    config->setGroup( oldGroup );
+
+  }  
+  
   //
   // Open file(s) after editor has been displayed.
   // Main reason: If anything goes wrong and an error dialog box
@@ -488,31 +484,10 @@ void KHexEdit::addRecentFile( const QString &fileName )
     return;
   }
 
-  uint recentCount = mAction.openRecent->popupMenu()->count();
-  for( uint id=0; id < recentCount; id++ )
-  {
-    QString text = mAction.openRecent->popupMenu()->text(id);
-    if( text.isNull() == true )
-    {
-      continue;
-    }
+  const KURL url( KURL::fromPathOrURL( fileName ) );
+  kdDebug(1501) << k_funcinfo << " adding recent " << fileName << " => " << url.prettyURL() << endl;
+  mAction.openRecent->addURL( url );
 
-    if( fileName == text )
-    {
-      mAction.openRecent->popupMenu()->removeItem(id);
-    }
-  }
-
-  while( mAction.openRecent->popupMenu()->count() >= 5 )
-  {
-    mAction.openRecent->popupMenu()->removeItemAt(4);
-  }
-
-  mAction.openRecent->popupMenu()->insertItem( fileName, 0, 0 );
-  for( uint i = 0; i < 5; i++ )
-  {
-    mAction.openRecent->popupMenu()->setId( i, i );
-  }
 }
 
 
@@ -528,26 +503,9 @@ void KHexEdit::removeRecentFile( const QString &fileName )
     return;
   }
 
-  uint recentCount = mAction.openRecent->popupMenu()->count();
-  uint i;
+  const KURL url( KURL::fromPathOrURL( fileName ) );
+  mAction.openRecent->removeURL( url );
 
-  for( i=0; i < recentCount; i++ )
-  {
-    QString text = mAction.openRecent->popupMenu()->text(i);
-    if( text.isNull() )
-    {
-      continue;
-    }
-
-    if( fileName == text )
-    {
-      mAction.openRecent->popupMenu()->removeItem(i);
-    }
-  }
-  for( i = 0; i < 5; i++ )
-  {
-    mAction.openRecent->popupMenu()->setId( i, i );
-  }
 }
 
 
@@ -559,47 +517,27 @@ void KHexEdit::renameRecentFile(const QString &curName, const QString &newName)
   }
   else
   {
-    for( uint i=0; i <  mAction.openRecent->popupMenu()->count(); i++ )
-    {
-      QString text = mAction.openRecent->popupMenu()->text(i);
-      if( text.isNull() ) { continue; }
-
-      if( curName == text )
-      {
-	mAction.openRecent->popupMenu()->changeItem( newName, i );
-	break;
-      }
-    }
+      mAction.openRecent->removeURL( KURL::fromPathOrURL( curName ) );
+      mAction.openRecent->addURL( KURL::fromPathOrURL( newName ) );
   }
 }
 
 
-void KHexEdit::recentFile( int id )
-{
-  //
-  // 2000-01-02 Espen Sand
-  // For some reason I sometimes get a segfault when I open the
-  // file directly from this slot. It used to work, but at some
-  // point of Qt (2.x) upgrades this began to happen. To avoid
-  // the problem I delay the opening until the program runs in
-  // the main event loop.
-  //
-  mRecentFileId = id;
-  QTimer::singleShot(0, this, SLOT(delayedRecentOpen()) );
-}
 
-
-void KHexEdit::delayedRecentOpen( void )
+void KHexEdit::slotFileOpenRecent( const KURL& url )
 {
-  QString url = mAction.openRecent->popupMenu()->text(mRecentFileId);
-  if( url.isNull() == false )
+  if ( url.isLocalFile() )
   {
-    editor()->open( url, false, 0 );
+    editor()->open( url.path(), false, 0 );
+  }
+  else
+  {
+    // ### TODO: support network transparency
+    KMessageBox::error( this, i18n("Non local recent file: %1").arg( url.prettyURL() ) );
   }
 }
 
 
-
 KHexEdit *KHexEdit::newWindow( void )
 {
   KHexEdit *hexEdit = new KHexEdit;
@@ -656,11 +594,6 @@ void KHexEdit::closeProgram( void )
       }
     }
 
-    //
-    // Save the order in the Recent queue to a list. This list will be written
-    // to disk.
-    //
-    makeExitFileList();
 
     //
     // Ths will write current configuration to disk.
@@ -690,12 +623,6 @@ void KHexEdit::closeProgram( void )
 
 bool KHexEdit::queryClose( void )
 {
-  //
-  // Save the order in the Recent queue to a list. This list will be written
-  // to disk.
-  //
-  makeExitFileList();
-
   bool success = editor()->closeAll();
   if( success == true )
   {
@@ -715,46 +642,6 @@ bool KHexEdit::queryExit( void )
   return( true );
 }
 
-
-void KHexEdit::makeExitFileList( void )
-{
-  //
-  // Note: I append five names, even if they are empty because the recent
-  // menu contains fewer. This is important because otherwise we may end up
-  // having duplicate entries in the config. file.
-  //
-
-  mExitFileList.clear();
-  mExitOffsetList.clear();
-
-  if( editor()->discardRecentFiles() == true )
-  {
-    for( uint i=0; i < 5; i++ )
-    {
-      mExitFileList.append(QString(""));
-      mExitOffsetList.append( QString("0") );
-    }
-  }
-  else
-  {
-    uint offset;
-    for( uint i=0; i < 5; i++ )
-    {
-      mExitFileList.append(mAction.openRecent->popupMenu()->text(i));
-      if( editor()->isOpen( mAction.openRecent->popupMenu()->text(i), offset )
-	  == true )
-      {
-	mExitOffsetList.append( QString("%1").arg(offset,0,16) );
-      }
-      else
-      {
-	mExitOffsetList.append( QString("%1").arg(0,0,16) );
-      }
-    }
-  }
-}
-
-
 void KHexEdit::readConfiguration( void )
 {
   KConfig &config = *kapp->config();
@@ -778,12 +665,10 @@ void KHexEdit::writeConfiguration( KConfig &config )
   config.writeEntry("TabBarPosition", (int)mManager->tabBarPosition());
   config.writeEntry("SearchBarPosition", (int)mManager->searchBarPosition());
 
-  for( uint i=0; i < mExitFileList.count(); i++ )
-  {
-    config.writePathEntry( QString("Recent%1").arg(i+1), *mExitFileList.at(i) );
-  }
-  config.writeEntry( QString("Offset"), mExitOffsetList );
-
+  if ( editor()->discardRecentFiles() )
+      mAction.openRecent->clearURLList();
+  mAction.openRecent->saveEntries( &config );
+  
   converter()->writeConfiguration( config );
   editor()->writeConfiguration( config );
 
@@ -845,17 +730,7 @@ void KHexEdit::readConfiguration( KConfig &config )
   mAction.searchShowBelowEditor->blockSignals(false);
   showSearchBar();
 
-  for( uint i = 0; i < 5; i++ )
-  {
-    QString fileName = config.readPathEntry( QString("Recent%1").arg(i+1) );
-    if( fileName.isEmpty() == false )
-    {
-      int pos = mAction.openRecent->popupMenu()->count();
-      mAction.openRecent->popupMenu()->insertItem( fileName, pos, pos );
-    }
-  }
-
-  mRecentOffsetList = config.readListEntry(QString("Offset") );
+  mAction.openRecent->loadEntries( &config );
 
   converter()->readConfiguration( config );
   editor()->readConfiguration( config );
