@@ -9,7 +9,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: daemon_state.cpp 253533 2003-09-24 10:53:00Z mueller $
+ * $Id: daemon_state.cpp 407526 2005-04-24 14:42:13Z goettsche $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -153,7 +153,9 @@ void daemon_state::load()
 
 
 	config->setGroup("BatteryLow");
-        low[0] = config->readNumEntry("LowVal", 15);
+        time_based_action_low = config->readBoolEntry("TimeBasedAction", true);
+        low[0] = config->readNumEntry("LowValTime", 15);
+        low[1] = config->readNumEntry("LowValPercent", 7);
         runCommand[0] = config->readBoolEntry("RunCommand", false)&exists;
         runCommandPath[0] = config->readEntry("RunCommandPath");
         playSound[0] = config->readBoolEntry("PlaySound", false)&exists;
@@ -177,7 +179,9 @@ void daemon_state::load()
         	have_time = 1;
 
 	config->setGroup("BatteryCritical");
-        low[1] = config->readNumEntry("LowVal", 5);
+        time_based_action_critical = config->readBoolEntry("TimeBasedAction", true);
+        low[2] = config->readNumEntry("CriticalValTime", 5);
+        low[3] = config->readNumEntry("CriticalValPercent", 3);
         runCommand[1] = config->readBoolEntry("RunCommand", false)&exists;
         runCommandPath[1] = config->readEntry("RunCommandPath");
         playSound[1] = config->readBoolEntry("PlaySound", false)&exists;
