@@ -4,7 +4,7 @@
  *
  * This file contains the docked widget for the laptop battery monitor
  *
- * $Id: daemondock.cpp 367683 2004-12-01 18:33:39Z mkoller $
+ * $Id: daemondock.cpp 437932 2005-07-23 16:30:44Z binner $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -264,7 +264,7 @@ void laptop_dock::slotGoRoot(int /*id*/) {
 
 
 void laptop_dock::slotHide() {
-	int confirm = KMessageBox::questionYesNo(0, i18n("Are you sure you want to hide the battery monitor? Your battery will still be monitored in the background."), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "hideConfirm");
+	int confirm = KMessageBox::questionYesNo(0, i18n("Are you sure you want to hide the battery monitor? Your battery will still be monitored in the background."), QString::null, i18n("Hide Monitor"), i18n("Do Not Hide"), "hideConfirm");
 
 	if (confirm != KMessageBox::Yes)
 		return;
@@ -282,12 +282,12 @@ void laptop_dock::slotHide() {
 
 
 void laptop_dock::slotQuit() {
-	int confirm = KMessageBox::questionYesNo(0, i18n("Are you sure you want to quit the battery monitor?"), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "quitConfirm");
+	int confirm = KMessageBox::questionYesNo(0, i18n("Are you sure you want to quit the battery monitor?"), QString::null, KStdGuiItem::quit(), KStdGuiItem::cancel(), "quitConfirm");
 
 	if (confirm != KMessageBox::Yes)
 		return;
 
-	confirm = KMessageBox::questionYesNo(0, i18n("Do you wish to disable the battery monitor from starting in the future?"), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "restartMonitor");
+	confirm = KMessageBox::questionYesNo(0, i18n("Do you wish to disable the battery monitor from starting in the future?"), QString::null, i18n("Disable"), i18n("Keep Enabled"), "restartMonitor");
 
 	if (confirm == KMessageBox::Yes) {
 		// just tell ourselves to hide the battery
@@ -371,7 +371,7 @@ void laptop_dock::mousePressEvent( QMouseEvent *event )
 					QString num3;
 					num3.setNum(pdaemon->left%60);
 					num3 = num3.rightJustify(2, '0');
-					tmp = i18n("%1:%2 time left").arg(pdaemon->left/60).arg(num3);
+					tmp = i18n("%1:%2 hours left").arg(pdaemon->left/60).arg(num3);
 				} else {
 					// no remaining time available
 					tmp = i18n("%1% charged").arg(pdaemon->val);
@@ -638,7 +638,7 @@ quit:
 				QString num3;
 				num3.setNum(pdaemon->left%60);
 				num3 = num3.rightJustify(2, '0');
-				tmp = i18n("Plugged in - %1% charged (%2:%3 time left)")
+				tmp = i18n("Plugged in - %1% charged (%2:%3 hours left)")
 					.arg(pdaemon->val).arg(pdaemon->left/60).arg(num3);
 			} else {
 				// no remaining time available
@@ -653,7 +653,7 @@ quit:
 				QString num3;
 				num3.setNum(pdaemon->left%60);
 				num3 = num3.rightJustify(2, '0');
-				tmp = i18n("Running on batteries - %1% charged (%2:%3 time left)")
+				tmp = i18n("Running on batteries - %1% charged (%2:%3 hours left)")
 						.arg(pdaemon->val).arg(pdaemon->left/60).arg(num3);
 			} else {
 				tmp = i18n("Running on batteries - %1% charged").arg(pdaemon->val);
