@@ -1,7 +1,7 @@
 /*
  * portable.cpp
  *
- * $Id: portable.cpp 389388 2005-02-14 16:53:47Z waba $
+ * $Id: portable.cpp 457925 2005-09-07 01:03:15Z ivor $
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
@@ -689,10 +689,29 @@ has_acpi_sleep(int state)
 	if (known != last_seed) {
 		known = last_seed;
 		mask = 0;
+
+		QFile p("/sys/power/state");
 		QFile f("/proc/acpi/sleep");
-		if (f.open(IO_ReadOnly)) {
+
+		if (p.open(IO_ReadOnly)) {
 			QString l;
-	       		f.readLine(l, 500);
+			p.readLine(l,500);
+			QStringList ll = QStringList::split(' ',l,false);
+			for (QValueListIterator<QString> i = ll.begin(); i!=ll.end(); i++) {
+				QString s = *i;
+				
+				if (s.compare("standby")==0)
+				mask |= (1<<1);
+				else if (s.compare("mem")==0)
+				mask |= (1<<3);
+				else if (s.compare("disk")==0)
+				mask |= (1<<4);
+			}
+			p.close();
+		}
+		else if (f.open(IO_ReadOnly)) {
+			QString l;
+			f.readLine(l, 500);
 			QStringList ll = QStringList::split(' ',l,false);
 			for (QValueListIterator<QString> i = ll.begin(); i!=ll.end(); i++) {
 				QString s = *i;
@@ -1363,7 +1382,9 @@ acpi_sleep_access_ok()
 	if (known != last_seed) {
 		known = last_seed;
 	    	known_res = (::access("/proc/acpi/sleep", R_OK|W_OK)==0 && ::acpi_helper_ok(1)) ||
- 	                    (::access("/proc/acpi/sleep", R_OK)==0 && ::acpi_helper_ok(0));
+ 	                    (::access("/proc/acpi/sleep", R_OK)==0 && ::acpi_helper_ok(0)) ||
+	    	            (::access("/sys/power/state", R_OK|W_OK)==0 && ::acpi_helper_ok(1)) ||
+ 	                    (::access("/sys/power/state", R_OK)==0 && ::acpi_helper_ok(0));
 	}
 	return(known_res);
 }
@@ -2152,7 +2173,7 @@ KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 //
 QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
 {
- 	QLabel* note = new QLabel(i18n(" "), parent);
+ 	QLabel* note = new QLabel(" ", parent);
 	return(note);
 }
 
@@ -2558,7 +2579,7 @@ KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
 {
 	// INSERT HERE
-       QLabel* note = new QLabel(i18n(" "), parent);
+       QLabel* note = new QLabel(" ", parent);
        return(note);
 }
 
@@ -2851,7 +2872,7 @@ KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 //
 QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
 {
- 	QLabel* note = new QLabel(i18n(" "), parent);
+ 	QLabel* note = new QLabel(" ", parent);
 	// INSERT HERE
 	return(note);
 }
