@@ -29,6 +29,8 @@
 
 struct tagitem;
 
+namespace KMilo {
+
 class PowerBookMonitor : public KMilo::Monitor
 {
 public:
@@ -48,4 +50,6 @@ private:
 	bool m_sleep;
 };
 
+}
+
 #endif
