@@ -18,15 +18,17 @@
 
 #ifndef UTIL_H
 #define UTIL_H
+
 #include <qpixmap.h>
-#include <qstring.h>
+#include <qiconset.h>
 
 class Util
 {
 public:
     static QPixmap getKRegExpEditorIcon( const QString& name );
     static QPixmap getSystemIcon( const QString& name );
+    static QIconSet getSystemIconSet( const QString& name );
 };
 
-#endif /* UTIL_H */
+#endif // UTIL_H
 
